Language-specific files for Mohawk

IPA Phoneset:

a, ˈa, aː, áː, àː, ʌ̃, ˈʌ̃, ʌ̃ː, ʌ̃̀ː, ʌ̃́ː, e, ˈe, èː, éː, i, ˈi, iː, íː, ìː, k, ɡ, kʷ, ɡʷ, kʰʷ, n, ũ, ˈũ, ṹː, ũ̀ː, o, ˈo, òː, óː, r, t, d, d͡ʒ, t͡ʃ, ʃ, s, w, f, j, ʔ